@@ -39,14 +39,14 @@ if ($rep) {
 	$svnrep = new SVNRepository($rep);
 
 	// If there's no revision info, go to the lastest revision for this path
-	$history = $svnrep->getLog($path, '', '', true, 2, $peg);
+	$history = $svnrep->getLog($path, 'HEAD', 1, true, 2, $peg);
 	$youngest = ($history) ? $history->entries[0]->rev : 0;
 
 	if (empty($rev)) {
 		$rev = $youngest;
 	}
 
-	$history = $svnrep->getLog($path, $rev, '', false, 2, $peg);
+	$history = $svnrep->getLog($path, $rev, 1, false, 2, $peg);
 
 	if ($path{0} != '/') {
 		$ppath = '/'.$path;
@@ -56,7 +56,7 @@ if ($rep) {
 
 	$prevrev = @$history->entries[1]->rev;
 
-	$vars['path'] = htmlentities($ppath, ENT_QUOTES, 'UTF-8');
+	$vars['path'] = escape($ppath);
 	$vars['rev1'] = $rev;
 	$vars['rev2'] = $prevrev;
 	$vars['prevrev'] = $prevrev;
@@ -74,7 +74,27 @@ if ($rep) {
 
 	if ($rev != $youngest) {
 		$vars['goyoungesturl'] = $config->getURL($rep, $path, 'diff').($peg ? 'peg='.$peg : '');
-		$vars['goyoungestlink'] = '<a href="'.$vars['goyoungesturl'].'">'.$lang['GOYOUNGEST'].'</a>';
+		$vars['goyoungestlink'] = '<a href="'.$vars['goyoungesturl'].'"'.($youngest ? ' title="'.$lang['REV'].' '.$youngest.'"' : '').'>'.$lang['GOYOUNGEST'].'</a>';
+	}
+
+	$revurl = $config->getURL($rep, $path, 'diff');
+	if ($rev < $youngest) {
+		$history2 = $svnrep->getLog($path, $rev, $youngest, false, 2, $peg ? $peg : 'HEAD');
+		if (isset($history2->entries[1])) {
+			$nextRev = $history2->entries[1]->rev;
+			if ($nextRev != $youngest) {
+				$vars['nextrev'] = $nextRev;
+				$vars['nextrevurl'] = $revurl.createRevAndPegString($nextRev, $peg);
+			}
+		}
+		unset($vars['error']);
+	}
+
+	if (isset($history->entries[1])) {
+		$prevRev = $history->entries[1]->rev;
+		$prevPath = $history->entries[1]->path;
+		$vars['prevrev'] = $prevRev;
+		$vars['prevrevurl'] = $revurl.createRevAndPegString($prevRev, $peg);
 	}
 
 	$vars['revurl'] = $config->getURL($rep, $path, 'revision').$passRevString;
@@ -122,27 +142,40 @@ if ($rep) {
 
 		// Get the contents of the two files
 		$newerFile = tempnam($config->getTempDir(), '');
-		$highlightedNew = $svnrep->getFileContents($history->entries[0]->path, $newerFile, $history->entries[0]->rev, $peg, '', true);
+		$newerFileHl = $newerFile.'highlight';
+		$normalNew = $svnrep->getFileContents($history->entries[0]->path, $newerFile, $history->entries[0]->rev, $peg, '', 'no');
+		$highlightedNew = $svnrep->getFileContents($history->entries[0]->path, $newerFileHl, $history->entries[0]->rev, $peg, '', 'line');
 
 		$olderFile = tempnam($config->getTempDir(), '');
-		$highlightedOld = $svnrep->getFileContents($history->entries[1]->path, $olderFile, $history->entries[1]->rev, $peg, '', true);
+		$olderFileHl = $olderFile.'highlight';
+		$normalOld = $svnrep->getFileContents($history->entries[0]->path, $olderFile, $history->entries[1]->rev, $peg, '', 'no');
+		$highlightedOld = $svnrep->getFileContents($history->entries[0]->path, $olderFileHl, $history->entries[1]->rev, $peg, '', 'line');
 		// TODO: Figured out why diffs across a move/rename are currently broken.
 
-		$ent = (!$highlightedNew && !$highlightedOld);
-		$listing = do_diff($all, $ignoreWhitespace, $ent, $newerFile, $olderFile);
+		$highlighted = ($highlightedNew && $highlightedOld);
+		if ($highlighted) {
+			$listing = do_diff($all, $ignoreWhitespace, $highlighted, $newerFile, $olderFile, $newerFileHl, $olderFileHl);
+		} else {
+			$listing = do_diff($all, $ignoreWhitespace, $highlighted, $newerFile, $olderFile, null, null);
+		}
 
 		// Remove our temporary files
 		@unlink($newerFile);
 		@unlink($olderFile);
+		@unlink($newerFileHl);
+		@unlink($olderFileHl);
 	}
 
 	if (!$rep->hasReadAccess($path, false)) {
 		$vars['error'] = $lang['NOACCESS'];
+		checkSendingAuthHeader($rep);
 	}
+
+} else {
+	header('HTTP/1.x 404 Not Found', true, 404);
 }
 
 $vars['template'] = 'diff';
-$template = ($rep) ? $rep->getTemplatePath() : $config->getTemplatePath();
-parseTemplate($template.'header.tmpl', $vars, $listing);
-parseTemplate($template.'diff.tmpl', $vars, $listing);
-parseTemplate($template.'footer.tmpl', $vars, $listing);
+parseTemplate('header.tmpl');
+parseTemplate('diff.tmpl');
+parseTemplate('footer.tmpl');
