@@ -230,6 +230,7 @@ class Repository {
 	var $minDownloadLevel;
 	var $allowedExceptions = array();
 	var $disallowedExceptions = array();
+	var $logsShowChanges;
 	var $rss;
 	var $rssCaching;
 	var $rssMaxEntries;
@@ -238,6 +239,7 @@ class Repository {
 	var $ignoreWebSVNContentTypes;
 	var $bugtraq;
 	var $auth;
+	var $authBasicRealm;
 	var $templatePath = false;
 
 	// }}}
@@ -284,6 +286,19 @@ class Repository {
 
 	// Local configuration accessors
 
+	function setLogsShowChanges($enabled = true) {
+		$this->logsShowChanges = $enabled;
+	}
+
+	function logsShowChanges() {
+		global $config;
+
+		if (isset($this->logsShowChanges))
+			return $this->logsShowChanges;
+		else
+			return $config->logsShowChanges();
+	}
+
 	// {{{ RSS Feed
 
 	function setRssEnabled($enabled) {
@@ -512,15 +527,15 @@ class Repository {
 
 	// {{{ Authentication
 
-	function useAuthenticationFile($file) {
+	function useAuthenticationFile($file, $basicRealm = false) {
 		if (is_readable($file)) {
-			$this->auth = new Authentication($file);
+			$this->auth = new Authentication($file, $basicRealm);
 		} else {
 			die('Unable to read authentication file "'.$file.'"');
 		}
 	}
 
-	function hasReadAccess($path, $checkSubFolders = false) {
+	function &getAuth() {
 		global $config;
 
 		$a = null;
@@ -529,6 +544,13 @@ class Repository {
 		} else {
 			$a =& $config->getAuth();
 		}
+		return $a;
+	}
+
+	function hasReadAccess($path, $checkSubFolders = false) {
+		global $config;
+
+		$a =& $this->getAuth();
 
 		if (!empty($a)) {
 			return $a->hasReadAccess($this->svnName, $path, $checkSubFolders);
@@ -541,12 +563,7 @@ class Repository {
 	function hasUnrestrictedReadAccess($path) {
 		global $config;
 
-		$a = null;
-		if (isset($this->auth)) {
-			$a =& $this->auth;
-		} else {
-			$a =& $config->getAuth();
-		}
+		$a =& $this->getAuth();
 
 		if (!empty($a)) {
 			return $a->hasUnrestrictedReadAccess($this->svnName, $path);
@@ -598,6 +615,7 @@ class WebSvnConfig {
 	var $serverIsWindows = false;
 	var $multiViews = false;
 	var $useEnscript = false;
+	var $useEnscriptBefore_1_6_3 = false;
 	var $useGeshi = false;
 	var $inlineMimeTypes = array();
 	var $allowDownload = false;
@@ -605,12 +623,14 @@ class WebSvnConfig {
 	var $minDownloadLevel = 0;
 	var $allowedExceptions = array();
 	var $disallowedExceptions = array();
+	var $logsShowChanges = false;
 	var $rss = true;
 	var $rssCaching = false;
 	var $rssMaxEntries = 40;
 	var $spaces = 8;
 	var $bugtraq = false;
 	var $auth = '';
+	var $blockRobots = false;
 
 	var $templatePaths = array();
 	var $userTemplate = false;
@@ -690,7 +710,7 @@ class WebSvnConfig {
 					// we have to check if we already have a repo with the same svn name
 					$duplicate = false;
 					foreach ($this->_repositories as $knownRepos) {
-						if ($knownRepos->svnName == $repo->svnName && $knownRepos->subpath == $repo->subpath) {
+						if ($knownRepos->path == $repo->path && $knownRepos->subpath == $repo->subpath) {
 							$duplicate = true;
 							break;
 						}
@@ -728,7 +748,7 @@ class WebSvnConfig {
 		}
 
 		// Hack to return a string by reference; value retrieved at setup.php:414
-		$str = 'Unable to find repository "'.htmlentities($name, ENT_QUOTES, 'UTF-8').'".';
+		$str = 'Unable to find repository "'.escape($name).'".';
 		$error =& $str;
 		return $error;
 	}
@@ -773,14 +793,19 @@ class WebSvnConfig {
 	//
 	// Use Enscript to colourise listings
 
-	function useEnscript() {
+	function useEnscript($before_1_6_3 = false) {
 		$this->useEnscript = true;
+		$this->useEnscriptBefore_1_6_3 = $before_1_6_3;
 	}
 
 	function getUseEnscript() {
 		return $this->useEnscript;
 	}
 
+	function getUseEnscriptBefore_1_6_3() {
+		return $this->useEnscriptBefore_1_6_3;
+	}
+
 	// }}}
 
 	// {{{ GeSHi
@@ -809,6 +834,27 @@ class WebSvnConfig {
 		}
 	}
 
+	// }}}
+
+	// {{{ Show changed files by default on log.php
+
+	function setLogsShowChanges($enabled = true, $myrep = 0) {
+		if (empty($myrep)) {
+			$this->logsShowChanges = $enabled;
+		} else {
+			$repo =& $this->findRepository($myrep);
+			$repo->logsShowChanges = $enabled;
+		}
+	}
+
+	function logsShowChanges() {
+		return $this->logsShowChanges;
+	}
+
+	// }}}
+
+	// {{{ RSS
+
 	function setRssEnabled($enabled = true, $myrep = 0) {
 		if (empty($myrep)) {
 			$this->rss = $enabled;
@@ -822,8 +868,6 @@ class WebSvnConfig {
 		return $this->rss;
 	}
 
-	// {{{ RSS
-
 	function setRssCachingEnabled($enabled = true, $myrep = 0) {
 		if (empty($myrep)) {
 			$this->rssCaching = true;
@@ -1022,7 +1066,7 @@ class WebSvnConfig {
 			} else if (is_object($rep)) {
 				$url .= '/'.$rep->getDisplayName().str_replace('%2F', '/', rawurlencode($path));
 
-				if ($op != 'dir' && $op != 'file') {
+				if ($op && $op != 'dir' && $op != 'file') {
 					$params['op'] = $op;
 				}
 			}
@@ -1074,7 +1118,7 @@ class WebSvnConfig {
 					break;
 			}
 
-			if ($rep !== -1 && $op != 'index') {
+			if (is_object($rep) && $op != 'index') {
 				$params['repname'] = $rep->getDisplayName();
 			}
 			if (!empty($path)) {
@@ -1165,7 +1209,7 @@ class WebSvnConfig {
 	// Define the location of the enscript command
 
 	function setEnscriptPath($path) {
-		$this->_setPath($this->enscript, $path, 'enscript');
+		$this->_setPath($this->enscript, $path, 'enscript', '-q');
 	}
 
 	function getEnscriptCommand() {
@@ -1288,8 +1332,10 @@ class WebSvnConfig {
 			echo 'No template path added in config file';
 			exit;
 		}
-		if ($this->userTemplate !== false) return $this->userTemplate;
-		return $this->templatePaths[0];
+		if ($this->userTemplate !== false)
+			return $this->userTemplate;
+		else
+			return $this->templatePaths[0];
 	}
 
 	// }}}
@@ -1362,10 +1408,10 @@ class WebSvnConfig {
 		return $this->ignoreWebSVNContentTypes;
 	}
 
-	function useAuthenticationFile($file, $myrep = 0) {
+	function useAuthenticationFile($file, $myrep = 0, $basicRealm = false) {
 		if (empty($myrep)) {
 			if (is_readable($file)) {
-				$this->auth = new Authentication($file);
+				$this->auth = new Authentication($file, $basicRealm);
 			} else {
 				echo 'Unable to read authentication file "'.$file.'"';
 				exit;
@@ -1380,6 +1426,14 @@ class WebSvnConfig {
 		return $this->auth;
 	}
 
+	function areRobotsBlocked() {
+		return $this->blockRobots;
+	}
+
+	function setBlockRobots($value = true) {
+		$this->blockRobots = $value;
+	}
+
 	function useTreeView() {
 		$this->treeView = true;
 	}
@@ -1477,10 +1531,10 @@ class WebSvnConfig {
 	// The mergesort function preserves this order.
 
 	function sortByGroup() {
-		if (!empty($this->_repositories))
-		mergesort($this->_repositories, 'cmpGroups');
+		if (!empty($this->_repositories)) {
+			mergesort($this->_repositories, 'cmpGroups');
+		}
 	}
 
 	// }}}
 }
-	
\ No newline at end of file
