@@ -205,33 +205,10 @@ function listCharacterData($parser, $data) {
 			$data = trim($data);
 			if ($data === false || $data === '') return;
 
-			$y = 0;
-			$mo = 0;
-			$d = 0;
-			$h = 0;
-			$m = 0;
-			$s = 0;
-			sscanf($data, '%d-%d-%dT%d:%d:%d.', $y, $mo, $d, $h, $m, $s);
-
-			$mo = substr('00'.$mo, -2);
-			$d = substr('00'.$d, -2);
-			$h = substr('00'.$h, -2);
-			$m = substr('00'.$m, -2);
-			$s = substr('00'.$s, -2);
-
-			$committime = strtotime($y.'-'.$mo.'-'.$d.' '.$h.':'.$m.':'.$s.' GMT');
-
-			$curList->curEntry->date = strftime('%Y-%m-%d %H:%M:%S', $committime);
-
+			$committime = parseSvnTimestamp($data);
 			$curList->curEntry->committime = $committime;
-			$curtime = time();
-
-			// Get the number of seconds since the commit
-			$agesecs = $curtime - $committime;
-			if ($agesecs < 0) $agesecs = 0;
-
-			$curList->curEntry->age = datetimeFormatDuration($agesecs, true, true);
-
+			$curList->curEntry->date = strftime('%Y-%m-%d %H:%M:%S', $committime);
+			$curList->curEntry->age = datetimeFormatDuration(max(time() - $committime, 0), true, true);
 			break;
 	}
 }
@@ -346,33 +323,10 @@ function logCharacterData($parser, $data) {
 			$data = trim($data);
 			if ($data === false || $data === '') return;
 
-			$y = 0;
-			$mo = 0;
-			$d = 0;
-			$h = 0;
-			$m = 0;
-			$s = 0;
-			sscanf($data, '%d-%d-%dT%d:%d:%d.', $y, $mo, $d, $h, $m, $s);
-
-			$mo = substr('00'.$mo, -2);
-			$d = substr('00'.$d, -2);
-			$h = substr('00'.$h, -2);
-			$m = substr('00'.$m, -2);
-			$s = substr('00'.$s, -2);
-
-			$committime = strtotime($y.'-'.$mo.'-'.$d.' '.$h.':'.$m.':'.$s.' GMT');
-
-			$curLog->curEntry->date = strftime('%Y-%m-%d %H:%M:%S', $committime);
-
+			$committime = parseSvnTimestamp($data);
 			$curLog->curEntry->committime = $committime;
-			$curtime = time();
-
-			// Get the number of seconds since the commit
-			$agesecs = $curtime - $committime;
-			if ($agesecs < 0) $agesecs = 0;
-
-			$curLog->curEntry->age = datetimeFormatDuration($agesecs, true, true);
-
+			$curLog->curEntry->date = strftime('%Y-%m-%d %H:%M:%S', $committime);
+			$curLog->curEntry->age = datetimeFormatDuration(max(time() - $committime, 0), true, true);
 			break;
 
 		case 'MSG':
@@ -563,19 +517,32 @@ class SVNRepository {
 
 	// }}}
 
+	// Private function to simplify creation of common SVN command string text.
+	function svnCommandString($command, $path, $rev, $peg) {
+		global $config;
+		return $config->getSvnCommand().' '.$command.' '.$this->repConfig->svnParams().($rev ? '-r '.$rev.' ' : '').quote(encodePath($this->getSvnPath($path)).'@'.($peg ? $peg : ''));
+	}
+
+	// Private function to simplify creation of enscript command string text.
+	function enscriptCommandString($l) {
+		global $config;
+		return $config->enscript.' --language=html '.($l ? '--color --'.(!$config->getUseEnscriptBefore_1_6_3() ? 'highlight' : 'pretty-print').'='.$l : '').' -o -';
+	}
+
 	// {{{ getFileContents
 	//
 	// Dump the content of a file to the given filename
 
-	function getFileContents($path, $filename, $rev = 0, $peg = '', $pipe = '', $perLineHighlighting = false) {
+	function getFileContents($path, $filename, $rev = 0, $peg = '', $pipe = '', $highlight = 'file') {
 		global $config, $extEnscript;
+		assert ($highlight == 'file' || $highlight == 'no' || $highlight == 'line');
 
 		$highlighted = false;
 
 		// If there's no filename, just deliver the contents as-is to the user
 		if ($filename == '') {
-			$path = encodepath($this->getSvnPath($path));
-			passthruCommand($config->getSvnCommand().' cat '.$this->repConfig->svnParams().quote($path.'@'.$rev).' '.$pipe);
+			$cmd = $this->svnCommandString('cat', $path, $rev, $peg);
+			passthruCommand($cmd.' '.$pipe);
 			return $highlighted;
 		}
 
@@ -584,28 +551,24 @@ class SVNRepository {
 		$ext = strrchr($path, '.');
 
 		$tempname = $filename;
-		if ($perLineHighlighting) {
+		if ($highlight == 'line') {
 			$tempname = tempnam($config->getTempDir(), '');
 		}
 		$highlighted = true;
-		if ($config->useGeshi && $geshiLang = $this->highlightLanguageUsingGeshi($ext)) {
+		if ($highlight != 'no' && $config->useGeshi && $geshiLang = $this->highlightLanguageUsingGeshi($ext)) {
 			$this->applyGeshi($path, $tempname, $geshiLang, $rev, $peg);
-		} else if ($config->useEnscript) {
+		} else if ($highlight != 'no' && $config->useEnscript) {
 			// Get the files, feed it through enscript, then remove the enscript headers using sed
-			//
-			// Note that the sec command returns only the part of the file between <PRE> and </PRE>.
+			// Note that the sed command returns only the part of the file between <PRE> and </PRE>.
 			// It's complicated because it's designed not to return those lines themselves.
-
 			$l = @$extEnscript[$ext];
-			$path = encodepath($this->getSvnPath($path));
-			$cmd = quoteCommand($config->getSvnCommand().' cat '.$this->repConfig->svnParams().quote($path.'@'.$rev).' | '.
-				$config->enscript.' --language=html '.
-				($l ? '--color --pretty-print='.$l : '').' -o - | '.
-				$config->sed.' -n '.$config->quote.'1,/^<PRE.$/!{/^<\\/PRE.$/,/^<PRE.$/!p;}'.$config->quote.' > $tempname');
+			$cmd = $this->svnCommandString('cat', $path, $rev, $peg);
+			$cmd = quoteCommand($cmd.' | '.$this->enscriptCommandString($l).' | '.
+				$config->sed.' -n '.$config->quote.'1,/^<PRE.$/!{/^<\\/PRE.$/,/^<PRE.$/!p;}'.$config->quote.' > '.$tempname);
 		} else {
 			$highlighted = false;
-			$path = encodepath(str_replace(DIRECTORY_SEPARATOR, '/', $this->getSvnPath($path)));
-			$cmd = quoteCommand($config->getSvnCommand().' cat '.$this->repConfig->svnParams().quote($path.'@'.$rev).' > '.quote($filename));
+			$cmd = $this->svnCommandString('cat', $path, $rev, $peg);
+			$cmd = quoteCommand($cmd.' > '.quote($filename));
 		}
 		if (isset($cmd)) {
 			$descriptorspec = array(2 => array('pipe', 'w')); // stderr
@@ -619,16 +582,15 @@ class SVNRepository {
 			proc_close($resource);
 
 			if (!empty($error)) {
-				$error = toOutputEncoding(nl2br(str_replace('svn: ', '', $error)));
 				global $lang;
-				error_log($lang['BADCMD'].': '.$cmd);
+				error_log($lang['BADCMD'].': '.escape($cmd));
 				error_log($error);
 				global $vars;
-				$vars['warning'] = $error.'.';
+				$vars['warning'] = nl2br(escape(toOutputEncoding($error)));
 			}
 		}
 
-		if ($highlighted && $perLineHighlighting) {
+		if ($highlighted && $highlight == 'line') {
 			// If we need each line independently highlighted (e.g. for diff or blame)
 			// then we'll need to filter the output of the highlighter
 			// to make sure tags like <font>, <i> or <b> don't span lines
@@ -679,8 +641,6 @@ class SVNRepository {
 			}
 		}
 		return '';
-
-
 	}
 
 	// }}}
@@ -690,14 +650,8 @@ class SVNRepository {
 	// perform syntax highlighting using geshi
 
 	function applyGeshi($path, $filename, $language, $rev, $peg = '', $return = false) {
-		global $config;
-
-		$pegrev = ($peg) ? '@'.$peg : '';
-
 		// Output the file to the filename
-		$path = encodepath($this->getSvnPath($path));
-		$cmd = quoteCommand($config->getSvnCommand().' cat -r '.$rev.' '.$this->repConfig->svnParams().quote($path.$pegrev).' > '.quote($filename));
-
+		$cmd = quoteCommand($this->svnCommandString('cat', $path, $rev, $peg).' > '.quote($filename));
 		$descriptorspec = array(2 => array('pipe', 'w')); // stderr
 		$resource = proc_open($cmd, $descriptorspec, $pipes);
 		$error = '';
@@ -709,12 +663,11 @@ class SVNRepository {
 		proc_close($resource);
 
 		if (!empty($error)) {
-			$error = toOutputEncoding(nl2br(str_replace('svn: ', '', $error)));
 			global $lang;
-			error_log($lang['BADCMD'].': '.$cmd);
+			error_log($lang['BADCMD'].': '.escape($cmd));
 			error_log($error);
 			global $vars;
-			$vars['warning'] = 'Unable to cat file: '.$error.'.';
+			$vars['warning'] = 'Unable to cat file: '.nl2br(escape(toOutputEncoding($error)));
 			return;
 		}
 
@@ -725,7 +678,7 @@ class SVNRepository {
 		}
 		$this->geshi->set_source($source);
 		$this->geshi->set_language($language);
-		$this->geshi->set_header_type(GESHI_HEADER_DIV);
+		$this->geshi->set_header_type(GESHI_HEADER_NONE);
 		$this->geshi->set_overall_class('geshi');
 		$this->geshi->set_tab_width($this->repConfig->getExpandTabsBy());
 
@@ -755,13 +708,10 @@ class SVNRepository {
 			@unlink($tempname);
 		} else {
 			$pre = false;
-			$path = encodepath($this->getSvnPath($path));
-			$pegrev = ($peg) ? '@'.$peg : '';
-			$cmd = $config->getSvnCommand().' cat -r '.$rev.' '.$this->repConfig->svnParams().quote($path.$pegrev);
+			$cmd = $this->svnCommandString('cat', $path, $rev, $peg);
 			if ($config->useEnscript) {
 				$l = @$extEnscript[$ext];
-				$cmd .= ' | '.$config->enscript.' --language=html '.
-					($l ? '--color --pretty-print='.$l : '').' -o - | '.
+				$cmd .= ' | '.$this->enscriptCommandString($l).' | '.
 					$config->sed.' -n '.$config->quote.'/^<PRE.$/,/^<\\/PRE.$/p'.$config->quote;
 			} else {
 				$pre = true;
@@ -772,10 +722,10 @@ class SVNRepository {
 					echo '<pre>';
 				while (!feof($result)) {
 					$line = fgets($result, 1024);
-					if ($pre)
-						$line = replaceEntities($line, $this->repConfig);
-					else
-						$line = toOutputEncoding($line);
+					$line = toOutputEncoding($line);
+					if ($pre) {
+						$line = escape($line);
+					}
 					print hardspace($line);
 				}
 				if ($pre)
@@ -792,13 +742,7 @@ class SVNRepository {
 	// Dump the blame content of a file to the given filename
 
 	function getBlameDetails($path, $filename, $rev = 0, $peg = '') {
-		global $config;
-
-		$pegrev = ($peg) ? '@'.$peg : '';
-
-		$path = encodepath($this->getSvnPath($path));
-		$cmd = quoteCommand($config->getSvnCommand().' blame -r '.$rev.' '.$this->repConfig->svnParams().quote($path.$pegrev).' > '.quote($filename));
-
+		$cmd = quoteCommand($this->svnCommandString('blame', $path, $rev, $peg).' > '.quote($filename));
 		$descriptorspec = array(2 => array('pipe', 'w')); // stderr
 		$resource = proc_open($cmd, $descriptorspec, $pipes);
 		$error = '';
@@ -810,32 +754,39 @@ class SVNRepository {
 		proc_close($resource);
 
 		if (!empty($error)) {
-			$error = toOutputEncoding(nl2br(str_replace('svn: ', '', $error)));
 			global $lang;
-			error_log($lang['BADCMD'].': '.$cmd);
+			error_log($lang['BADCMD'].': '.escape($cmd));
 			error_log($error);
 			global $vars;
-			$vars['warning'] = 'No blame info: '.$error.'.';
+			$vars['warning'] = 'No blame info: '.nl2br(escape(toOutputEncoding($error)));
 		}
 	}
 
 	// }}}
 
+	function getProperties($path, $rev = 0, $peg = '') {
+		$cmd = $this->svnCommandString('proplist', $path, $rev, $peg);
+		$ret = runCommand($cmd, true);
+		$properties = array();
+		if (is_array($ret)) {
+			foreach ($ret as $line) {
+				if (substr($line, 0, 1) == ' ') {
+					$properties[] = ltrim($line);
+				}
+			}
+		}
+		return $properties;
+	}
+
 	// {{{ getProperty
 
 	function getProperty($path, $property, $rev = 0, $peg = '') {
-		global $config;
-
-		$path = encodepath($this->getSvnPath($path));
-		$pegrev = ($peg) ? '@'.$peg : '';
-
-		$ret = runCommand($config->getSvnCommand().' propget -r '.$rev.' '.$property.' '.$this->repConfig->svnParams().quote($path.$pegrev), true);
-
+		$cmd = $this->svnCommandString('propget '.$property, $path, $rev, $peg);
+		$ret = runCommand($cmd, true);
 		// Remove the surplus newline
 		if (count($ret)) {
 			unset($ret[count($ret) - 1]);
 		}
-
 		return implode("\n", $ret);
 	}
 
@@ -846,18 +797,12 @@ class SVNRepository {
 	// Exports the directory to the given location
 
 	function exportRepositoryPath($path, $filename, $rev = 0, $peg = '') {
-		global $config;
-
-		$path = encodepath($this->getSvnPath($path));
-		$pegrev = ($peg) ? '@'.$peg : '';
-
-		$cmd = $config->getSvnCommand().' export -r '.$rev.' '.$this->repConfig->svnParams().quote($path.$pegrev).' '.quote($filename);
-
+		$cmd = $this->svnCommandString('export', $path, $rev, $peg).' '.quote($filename);
 		$retcode = 0;
 		execCommand($cmd, $retcode);
 		if ($retcode != 0) {
 			global $lang;
-			error_log($lang['BADCMD'].': '.$cmd);
+			error_log($lang['BADCMD'].': '.escape($cmd));
 		}
 		return $retcode;
 	}
@@ -866,7 +811,7 @@ class SVNRepository {
 
 	// {{{ getList
 
-	function getList($path, $rev = 0) {
+	function getList($path, $rev = 0, $peg = '') {
 		global $config, $curList;
 
 		$xml_parser = xml_parser_create('UTF-8');
@@ -886,7 +831,6 @@ class SVNRepository {
 		$curList->path = $path;
 
 		// Get the list info
-		$path = encodepath($this->getSvnPath($path));
 
 		if ($rev == 0) {
 			$headlog = $this->getLog('/', '', '', true, 1);
@@ -894,7 +838,7 @@ class SVNRepository {
 				$rev = $headlog->entries[0]->rev;
 		}
 
-		$cmd = quoteCommand($config->getSvnCommand().' list --xml '.$this->repConfig->svnParams().quote($path.'@'.$rev));
+		$cmd = quoteCommand($this->svnCommandString('list --xml', $path, $rev, $peg));
 
 		$descriptorspec = array(0 => array('pipe', 'r'), 1 => array('pipe', 'w'), 2 => array('pipe', 'w'));
 
@@ -902,7 +846,7 @@ class SVNRepository {
 
 		if (!is_resource($resource)) {
 			global $lang;
-			echo $lang['BADCMD'].': <code>'.stripCredentialsFromCommand($cmd).'</code>';
+			echo $lang['BADCMD'].': <code>'.escape(stripCredentialsFromCommand($cmd)).'</code>';
 			exit;
 		}
 
@@ -944,15 +888,15 @@ class SVNRepository {
 		if (!empty($error)) {
 			$error = toOutputEncoding(nl2br(str_replace('svn: ', '', $error)));
 			global $lang;
-			error_log($lang['BADCMD'].': '.$cmd);
+			error_log($lang['BADCMD'].': '.escape($cmd));
 			error_log($error);
 			global $vars;
 			if (strstr($error, 'found format')) {
-				$vars['error'] = 'Repository uses a newer format than Subversion '.$config->getSubversionVersion().' can read. ("'.substr($error, strrpos($error, 'Expected')).'.")';
+				$vars['error'] = 'Repository uses a newer format than Subversion '.$config->getSubversionVersion().' can read. ("'.nl2br(escape(toOutputEncoding(substr($error, strrpos($error, 'Expected'))))).'.")';
 			} else if (strstr($error, 'No such revision')) {
-				$vars['warning'] = 'Revision '.$rev.' of this resource does not exist.';
+				$vars['warning'] = 'Revision '.escape($rev).' of this resource does not exist.';
 			} else {
-				$vars['error'] = $lang['BADCMD'].':<br/><br/><code>'.stripCredentialsFromCommand($cmd).'</code><br/><br/>'.$error;
+				$vars['error'] = $lang['BADCMD'].': <code>'.escape(stripCredentialsFromCommand($cmd)).'</code><br />'.nl2br(escape(toOutputEncoding($error)));
 			}
 			return null;
 		}
@@ -984,41 +928,22 @@ class SVNRepository {
 		$curLog->entries = array();
 		$curLog->path = $path;
 
-		$revStr = '';
-
-		if ($brev && $erev) {
-			$revStr = '-r'.$brev.':'.$erev;
-		} else if ($brev) {
-			$revStr = '-r'.$brev.':1';
-		}
+		// Get the log info
+		$effectiveRev = ($brev && $erev ? $brev.':'.$erev : ($brev ? $brev.':1' : ''));
+		$effectivePeg = ($peg ? $peg : ($brev ? $brev : ''));
+		$cmd = quoteCommand($this->svnCommandString('log --xml '.($quiet ? '--quiet' : '--verbose'), $path, $effectiveRev, $effectivePeg));
 
 		if (($config->subversionMajorVersion > 1 || $config->subversionMinorVersion >= 2) && $limit != 0) {
-			$revStr .= ' --limit '.$limit;
+			$cmd .= ' --limit '.$limit;
 		}
 
-		// Get the log info
-		$path = encodepath($this->getSvnPath($path));
-		$info = '--verbose';
-		if ($quiet)
-			$info = '--quiet';
-
-		if ($peg) {
-			$pegrev = '@'.$peg;
-		} else if ($brev) {
-			$pegrev = '@'.$brev;
-		} else {
-			$pegrev = '';
-		}
-
-		$cmd = quoteCommand($config->getSvnCommand().' log --xml '.$info.' '.$revStr.' '.$this->repConfig->svnParams().quote($path.$pegrev));
-
 		$descriptorspec = array(0 => array('pipe', 'r'), 1 => array('pipe', 'w'), 2 => array('pipe', 'w'));
 
 		$resource = proc_open($cmd, $descriptorspec, $pipes);
 
 		if (!is_resource($resource)) {
 			global $lang;
-			echo $lang['BADCMD'].': <br/><br/><code>'.stripCredentialsFromCommand($cmd).'</code>';
+			echo $lang['BADCMD'].': <code>'.escape(stripCredentialsFromCommand($cmd)).'</code>';
 			exit;
 		}
 
@@ -1057,17 +982,16 @@ class SVNRepository {
 		proc_close($resource);
 
 		if (!empty($error)) {
-			$error = toOutputEncoding(nl2br(str_replace('svn: ', '', $error)));
 			global $lang;
-			error_log($lang['BADCMD'].': '.$cmd);
+			error_log($lang['BADCMD'].': '.escape($cmd));
 			error_log($error);
 			global $vars;
 			if (strstr($error, 'found format')) {
-				$vars['error'] = 'Repository uses a newer format than Subversion '.$config->getSubversionVersion().' can read. ("'.substr($error, strrpos($error, 'Expected')).'.")';
+				$vars['error'] = 'Repository uses a newer format than Subversion '.$config->getSubversionVersion().' can read. ("'.nl2br(escape(toOutputEncoding(substr($error, strrpos($error, 'Expected'))))).'.")';
 			} else if (strstr($error, 'No such revision')) {
-				$vars['warning'] = 'Revision '.$brev.' of this resource does not exist.';
+				$vars['warning'] = 'Revision '.escape($brev).' of this resource does not exist.';
 			} else {
-				$vars['error'] = $lang['BADCMD'].':<br/><br/><code>'.stripCredentialsFromCommand($cmd).'</code><br/><br/>'.nl2br($error);
+				$vars['error'] = $lang['BADCMD'].': <code>'.escape(stripCredentialsFromCommand($cmd)).'</code><br />'.nl2br(escape(toOutputEncoding($error)));
 			}
 			return null;
 		}
@@ -1099,18 +1023,13 @@ class SVNRepository {
 				$curLog->entries[$entryKey]->age = '';
 			}
 		}
-
 		return $curLog;
 	}
 
 	// }}}
 
-	function isFile($path, $rev = '') {
-		global $config;
-
-		$path = encodepath($this->getSvnPath($path));
-		$pegrev = ($rev) ? '@'.$rev : '';
-		$cmd = $config->getSvnCommand().' info --xml '.$this->repConfig->svnParams().quote($path.$pegrev);
+	function isFile($path, $rev = 0, $peg = '') {
+		$cmd = $this->svnCommandString('info --xml', $path, $rev, $peg);
 		return strpos(implode(' ', runCommand($cmd, true)), 'kind="file"') !== false;
 	}
 
@@ -1129,17 +1048,10 @@ class SVNRepository {
 
 }
 
-// {{{ initSvnVersion
-
-function initSvnVersion() {
-	global $config;
-
-	$ret = runCommand(str_replace('--non-interactive', '--version', $config->getSvnCommand()), false);
-	if (preg_match('~([0-9]?)\.([0-9]?)\.([0-9]?)~', $ret[0], $matches)) {
-		$config->setSubversionVersion($matches[0]);
-		$config->setSubversionMajorVersion($matches[1]);
-		$config->setSubversionMinorVersion($matches[2]);
-	}
+// Initialize SVN version information by parsing from command-line output.
+$ret = runCommand(str_replace('--non-interactive', '--version', $config->getSvnCommand()), false);
+if (preg_match('~([0-9]?)\.([0-9]?)\.([0-9]?)~', $ret[0], $matches)) {
+	$config->setSubversionVersion($matches[0]);
+	$config->setSubversionMajorVersion($matches[1]);
+	$config->setSubversionMinorVersion($matches[2]);
 }
-
-// }}}
