@@ -36,18 +36,20 @@ $languages = array(
   'fr'    => array('french', 'French', 'Fran&ccedil;ais'),
   'de'    => array('german', 'German', 'Deutsch'),
   'he-IL' => array('hebrew', 'Hebrew', '&#1506;&#1489;&#1512;&#1497;&#1514;'),
+  'hin'   => array('hindi', 'Hindi', '&#2361;&#2367;&#2306;&#2342;&#2368;'),
   'hu'    => array('hungarian', 'Hungarian', 'Magyar'),
   'id'    => array('indonesian', 'Indonesian', 'Bahasa Indonesia'),
   'it'    => array('italian', 'Italian', 'Italiano'),
   'ja'    => array('japanese', 'Japanese', '&#26085;&#26412;&#35486;'),
   'ko'    => array('korean', 'Korean', '&#54620;&#44397;&#50612;'),
+  'mr'    => array('marathi', 'Marathi', '&#2350;&#2352;&#2366;&#2336;&#2368;'),
   'no'    => array('norwegian', 'Norwegian', 'Norsk'),
   'pl'    => array('polish', 'Polish', 'Polski'),
   'pt'    => array('portuguese', 'Portuguese', 'Portugu&ecirc;s'),
   'pt-BR' => array('portuguese-br', 'Portuguese (Brazil)', 'Portugu&ecirc;s'),
   'ru'    => array('russian', 'Russian', '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;'),
   'sk'    => array('slovak', 'Slovak', 'Sloven&#269;ina'),
-  'sl'    => array('slovenian', 'Slovenian', 'Sloven&#269;ina'),
+  'sl'    => array('slovenian', 'Slovenian', 'Sloven&#353;&#269;ina'),
   'es'    => array('spanish', 'Spanish', 'Espa&ntilde;ol'),
   'sv'    => array('swedish', 'Swedish', 'Svenska'),
   'tr'    => array('turkish', 'Turkish', 'T&uuml;rk&ccedil;e'),
